# Manual Clean-up

### 1. Destroy command
If running from code repo:
```shell
go run main.go destroy --cluster <your-stack-name> --refresh
```

If running using release binary:
```shell
./x-install destroy --cluster <your-stack-name> --refresh
```

### 2. Terraform destroy
`x-install` generates the terraform module files in the following location:
```
~/.xio
    └── <your-stack-name>
        ├── infra-k8s.state/
        ├── xio-iam.state/
        ├── xio.state/
        └── xkarpenter.state/
```

Go to each of the module directories manually if they still exist, and attempt a `terraform destroy`, in the following **order**:
1. `xkarpenter.state/`
1. `xio.state/`
1. `xio-iam.state/`
1. `infra-k8s.state/`

```shell
terraform destroy -auto-approve -refresh
```

### 3. Manually Delete Resources in the AWS Console
Go to AWS Console -> Select your region -> Delete the following resources that **match** your stack/cluster name, in the following **order**:
1. EKS Cluster
   1. This needs the node group(s) to be deleted first:
       - Go to EKS cluster <stack-name>
       - Go to the `Compute` tab
       - Select all node groups
       - Delete
    2. Delete the EKS cluster that matches your stack name.
2. EC2 instances
   - The management server's VM will have the termination (deletion) protection flag enabled. Disable it before deleting the VM by:
       - Go to the management server's EC2 instance
       - Click on `Actions`
       - Select `Instance settings`
       - Select `Change termination protection`
       - Uncheck the `Enable` checkbox
   - Terminate to delete the EC2 instance
3. VPC and related network resources
    - Delete the VPC that matches the stack name, and all the dependent network resources (subnet, route table, etc.)
4. IAM roles and policies
    - Delete all the IAM roles and policies that match the stack name.
    - In addition to the roles matching stack name, there will be one role (per run) for Terraform that starts with `terraform-` which has to be deleted manually. Also, the associated management server's instance profile. For ease, use the CLI commands as follows:
        ```shell
        # Get Terraform's IAM role name associated with the management server's instance profile
        aws iam get-instance-profile \
            --instance-profile-name <stack-name>-xio-mgmt-server \
            --query "InstanceProfile.Roles[*].RoleName" \
            --output json | jq '.[]'
        # Example output:
        #   "terraform-00000000000000000000000000"

        # Delete the IAM role using the role name from the last output. If multiple roles, run once per each.
        aws iam delete-role --role-name <role-name>

        # Delete the management server's instance profile
        aws iam delete-instance-profile \
            --instance-profile-name <stack-name>-xio-mgmt-server
        ```
5. CloudWatch log group(s)
    - Delete CloudWatch log group(s) that match the stack name.
6. KMS alias
    - Delete KMS alias(s) that match the stack name.
